( cd usr/share/doc/HTML/de/kvpnc ; rm -rf common )
( cd usr/share/doc/HTML/de/kvpnc ; ln -sf /usr/share/doc/HTML/de/common common )
( cd usr/share/doc/HTML/sv/kvpnc ; rm -rf common )
( cd usr/share/doc/HTML/sv/kvpnc ; ln -sf /usr/share/doc/HTML/sv/common common )
( cd usr/share/doc/HTML/en/kvpnc ; rm -rf common )
( cd usr/share/doc/HTML/en/kvpnc ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/fr/kvpnc ; rm -rf common )
( cd usr/share/doc/HTML/fr/kvpnc ; ln -sf /usr/share/doc/HTML/fr/common common )
