<!DOCTYPE kpartgui>
<kpartgui name="kvpncmenubar">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="serverConnect"/>
    <Action name="serverDisconnect"/>
  </Menu>
	<Menu name="Profile"><text>&amp;Profile</text>
		<Action name="advancedSettingsSession"/>
    <Action name="newSession"/>
		<Action name="NewProfileWizard"/>
		<Action name="saveSession"/>
		<Action name="renameSession"/>
		<Action name="deleteSession"/>
    <Separator/>
		<Action name="importSession"/>
		<Action name="importOpenvpnConfig"/>
		<Action name="importFreeswanConfig"/>
		<Separator/>
		<Action name="exportOpenvpnConfig"/>
		<Separator/>
		<Action name="importCert"/>
		<Action name="manageCiscoCert"/>
		<Action name="enrollCiscoCert"/>
</Menu>
	<Menu name="KVpnc"><text>&amp;KVpnc</text>
		<Action name="genOpenvpncKey"/>
		<Separator/>
		<Action name="debugconsole"/>
		<Action name="toolsinfo"/>
		<Action name="vpntypesinfo"/>
		<Action name="logviewer"/>
		<Separator/>
		<Action name="importKvpncSettings"/>
		<Action name="exportKvpncSettings"/>
  </Menu>
	<Menu name="help"><text>&amp;Help</text>
		<Action name="donate"/>
		<Action name="reportbug"/>
		<Action name="help_send_feedback_mail"/>
	</Menu>
</MenuBar>
<ToolBar name="mainToolBar">
    <Action name="serverConnect"/>
    <Action name="serverDisconnect"/>
		<Separator/>
		<Action name="profileManager"/>
		<Action name="NewProfileWizard"/>
		<Separator/>
		<Action name="preferences"/>
</ToolBar>
<StatusBar></StatusBar>
</kpartgui>