#!/bin/sh
LANGS="de fr sv"

echo -n "update pot..."
xml2pot en/index.docbook > en/handbook.pot
echo " done."

for lang in $LANGS; do
        echo -n "updating $lang..."
	mv $lang/handbook.po $lang/handbook_old.po
	msgmerge -o $lang/handbook.po $lang/handbook_old.po en/handbook.pot
	rm $lang/handbook_old.po
        po2xml en/index.docbook $lang/handbook.po > $lang/index.docbook
        echo " done."
done
